Results by GAYHALO results program 21/01/2017

Mrs S Hindle
Show | CC | RCC
Driffield 5th October 2006 | CH. Ricksbury Royal Hero | CH. Keyingham Branwell
Manchester 16th January 2008 | CH. Lochbuie Geordie | Merryoth Maeve
Darlington 20th September 2009 | CH. Maibee Make Believe | CH. Loranka Just Like Heaven JW
Blackpool 22nd June 2012 | CH. Loranka Sherrie Baby | Dear Magic Touch De La Fi Au Songeur
Welsh Kennel Club 2014 | Brymarden Carolina Sunrise | Ch. Wandris Evan Elp Us
Welsh Kennel Club 2014 | Ch. Charnell Clematis of Salegreen | CH. Byermoor Queens Maid